#!/usr/bin/env python
# -*- coding: utf-8 -*-
# 
# Copyright 2016 Aerospace Corporation.
# 
# This is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
# 
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this software; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
# 

from gnuradio import gr, blocks

class block_interleaver(gr.hier_block2):
    """Outputs block interleaved input samples
    
    This block takes blocks of length PERIOD input samples and outputs them
    according to standard block interleaver row write, column read with an
    optional circular shift of the row order.  The rows and columns of the 
    block interleaver equal the DEPTH and PERIOD / DEPTH, respectively.
    
    Example: DEPTH=3, PERIOD=6 with input=[1 2 3 4 5 6], output=[1 3 5 2 4 6]
    Example: DEPTH=3, PERIOD=6, SHIFT=1 with same input, output=[5 1 3 6 2 4]
    
    """
    def __init__(self, itemsize, depth, period, shift=0):
        super(block_interleaver, self).__init__(
            'block_interleaver',
            gr.io_signature(1, 1, itemsize),            
            gr.io_signature(1, 1, itemsize))
            
        rows, cols = depth, period // depth
        if rows * cols != period: 
            raise ValueError, "Period must be integer multiple of divide"
        shift %= rows
        deintlv = blocks.deinterleave(itemsize, cols)
        intlv = blocks.interleave(itemsize)
        
        self.connect(self, deintlv)
        for n in range(rows):
            self.connect((deintlv, n), (intlv, (n + shift) % rows))
        self.connect(intlv, self)

