##
# @brief MPDU Operations Message class.
# @author Miguel Dominguez
# @details There is no superclass for Operations Messages Classes because
# they basically have nothing in common, they are simply a container for
# some useful variables to be passed forward.
# @date 2016
class MPDUOpsMsg(object):

   ##
   # @fn __init__
   # @brief Constructor.
   # @details Initializes the message states to sane defaults
   def __init__(self):
      self.missedFrames = 0
      self.isNewTransportFrame = False
      self.vcID = 0

   ##
   # @fn setMissedFrames
   # @brief Setter for the number of missed frames according to VCDU counter
   # information
   # @param[in] missedFrames Count of missed frames
   # @warning Should this be handled in VCDU?
   # @warning Should probably not use getters and setters in Python
   # @warning Check MPDULayer logic, this number may not always be
   # correct in certain cases
   def setMissedFrames(self,missedFrames):
      self.missedFrames = missedFrames

   ##
   # @fn setMissedFrames
   # @brief Getter for the number of missed frames according to VCDU counter
   # information
   # @param[out] missedFrames Count of missed frames
   # @warning Should this be handled in VCDU?
   # @warning Should probably not use getters and setters in Python
   # @warning Check MPDULayer logic, this number may not always be
   # correct in certain cases
   def getMissedFrames(self):
      return self.missedFrames

   ##
   # @fn hasMissedFrames
   # @brief Convenience function to tell whether any missed frames were
   # detected.
   # @param[out] output True if missed frames were detected, false otherwise
   # @warning Should this be handled in VCDU?
   def hasMissedFrames(self):
   #   print(self.missedFrames)
      return (self.missedFrames > 0)

   ##
   # @fn setisNewTransportFrame
   # @brief Report whether the current MPDU frame contains a new Transport
   # frame.
   # @param[in] isNewTransportFrame Whether the current MPDU frame contains
   # a new Transport Frame
   # @warning Should probably not use getters and setters in Python
   # @warning This information isn't used downstream, coulld probably
   # be removed
   def setIsNewTransportFrame(self,isNewTransportFrame):
      self.isNewTransportFrame = isNewTransportFrame

   ##
   # @fn getisNewTransportFrame
   # @brief Return whether the current MPDU frame contains a new Transport
   # frame.
   # @param[out] isNewTransportFrame Whether the current MPDU frame contains
   # a new Transport Frame
   # @warning Should probably not use getters and setters in Python
   # @warning This information isn't used downstream, coulld probably
   # be removed
   def getIsNewTransportFrame(self):
      return self.isNewTransportFrame
