#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2016 The Aerospace Corporation.
#
# This is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this software; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street,
# Boston, MA 02110-1301, USA.
#

import traits.api as tr
import traitsui.api as trui

import pyface.qt.QtGui as qtgui
from pyface.qt.QtGui import QDesktopServices as qds
from pyface.qt.QtCore import QUrl
from pyface.api import AboutDialog, ImageResource

import os.path as osp
import config

AboutAction = trui.Action(id='About', name='&About', action='show_about', menu_role='About')
SaveAction = trui.Action(id='Save', name='&Save Config', action='do_save_config', accelerator='Ctrl+S')
LoadAction = trui.Action(id='Load', name='&Load Config', action='do_load_config', accelerator='Ctrl+O')
QuitAction = trui.Action(id='Quit', name='&Quit', action='do_quit', accelerator='Ctrl+Q')

top_menu_bar = trui.MenuBar('Top',  # top group
    trui.Menu('Top', SaveAction,
                     LoadAction,
                     QuitAction,
                     name='&File', id='File'),
    trui.Menu('Top', trui.HelpAction,     # action is show_help
                     AboutAction,
                     name='&Help', id='Help'),
    id='Top'
)

about = AboutDialog(additions=['xRIT/EMWIN Receiver v2.1.1','Copyright &copy; 2019 The Aerospace Corporation'],
                    image=ImageResource("noaa-goessdr_icon_128.png",
                                        search_path=[config.FREEDESKTOP_DIRECTORY,]))

class TopMenuHandler(trui.Handler):
    def do_quit(self, info):
        info.ui.dispose()
        qtgui.qApp.exit(0)     # TODO: why is this required to exit the app?

    def show_help(self, info):
        qds.openUrl(QUrl('file://' + config.HELP_INDEX))

    def show_about(self, info):
        about.open()

    def do_save_config(self, info):
        info.ui.context['object'].save_config()

    def do_load_config(self, info):
        info.ui.context['object'].load_config()

    # TODO: this function should be defined and used from scan_read_files_tab
    def _open_product_filters(self, info):
        obj = info.ui.context.get('object', None)
        obj.scan_read_files_tab.first._edit_filters(parent=info.ui.control)



from pyface.action.api import ActionController
class LocalActionController(ActionController):
    """Executes actions in a different handler context"""
    handler = tr.Instance(trui.Handler)
    info = tr.Instance(trui.UIInfo)

    def perform(self, action):
        from ipdb_for_qt import set_trace; set_trace()
        getattr(self.handler, action)(self.ui_info)
        return action.perform()    # post-executution calls
